@@ -5,7 +5,7 @@ from qingcloud.cli.iaas_client.actions.base import BaseAction
 class AllocateEipsAction(BaseAction):
 
     action = 'AllocateEips'
-    command = 'allocate-eip'
+    command = 'allocate-eips'
     usage = '%(prog)s --bandwidth <bandwidth> --count <count> [options] [-f <conf_file>]'
 
     @classmethod
@@ -13,23 +13,23 @@ class AllocateEipsAction(BaseAction):
 
         parser.add_argument('-c', '--count', dest='count',
                 action='store', type=int, default=1,
-                help='The number of the eips you want to allocate. Default 1')
+                help='the number of the eips you want to allocate. Default 1')
         
         parser.add_argument('-b', '--bandwidth', dest='bandwidth',
                 action='store', type=int, default=None,
-                help='The bandwidth of the eip. Unit is MB.')
+                help='the bandwidth of the eip. Unit is MB.')
      
         parser.add_argument('-i', '--need_icp', dest='need_icp',
                 action='store', type=int, default=0,
-                help='Whether need ICP code.')
+                help='whether need ICP code.')
         
         parser.add_argument('-g', '--eip_group', dest='eip_group',
                 action='store', type=str, default='',
-                help='The ID of eip group you want to allocate eips from.')
+                help='the ID of eip group you want to allocate eips from.')
          
         parser.add_argument('-n', '--eip_name', dest='eip_name',
                 action='store', type=str, default='',
-                help='The short name of eip')
+                help='the short name of eip')
 
     @classmethod
     def build_directive(cls, options):
