@@ -17,7 +17,7 @@ class CaptureInstanceAction(BaseAction):
 
         parser.add_argument('-N', '--image_name', dest='image_name',
                 action='store', type=str, default='',
-                help='A short name of the image.')
+                help='short name of the image.')
 
     @classmethod
     def build_directive(cls, options):
