@@ -7,13 +7,13 @@ class AddRouterStaticsAction(BaseAction):
 
     action = 'AddRouterStatics'
     command = 'add-router-statics'
-    usage = '%(prog) -r <router_id> -v <vxnet_id> -s <statics> [-f <conf_file>]'
+    usage = '%(prog)s -r <router_id> -s <statics> [-f <conf_file>]'
 
     @classmethod
     def add_ext_arguments(cls, parser):
         parser.add_argument('-r', '--router', dest='router',
                 action='store', type=str, default='',
-                help='The ID of router you want to add statics to.')
+                help='the ID of router you want to add statics to.')
 
         parser.add_argument('-s', '--statics', dest='statics',
                 action='store', type=str, default='',
