@@ -13,15 +13,15 @@ class ModifyVolumeAttributesAction(BaseAction):
      
         parser.add_argument('-v', '--volume_id', dest='volume_id',
                 action='store', type=str, default='',
-                help='The id of the volume whose attributes you want to modify.')
+                help='the id of the volume whose attributes you want to modify.')
                 
         parser.add_argument('-N', '--volume_name', dest='volume_name',
                 action='store', type=str, default='',
-                help='Specify the new volume name.')
+                help='specify the new volume name.')
 
         parser.add_argument('-D', '--description', dest='description',
                 action='store', type=str, default='',
-                help='The detailed description of the resource.')
+                help='the detailed description of the resource.')
 
     @classmethod
     def build_directive(cls, options):
